@@ -1,5 +1,5 @@
 package DBIx::Lite::ResultSet;
-$DBIx::Lite::ResultSet::VERSION = '0.32';
+$DBIx::Lite::ResultSet::VERSION = '0.33';
 use strict;
 use warnings;
 
@@ -527,7 +527,7 @@ sub count {
     my $count;
     $self->{dbix_lite}->dbh_do(sub {
         # Postgres throws an error when using ORDER BY clauses with COUNT(*)
-        my $count_rs = $self->select(\ "-COUNT(*)")->order_by(undef);
+        my $count_rs = $self->select(\ "COUNT(*)")->order_by(undef);
         my ($sth, @bind) = $count_rs->select_sth;
         $sth->execute(@bind);
         $count = +($sth->fetchrow_array)[0];
@@ -717,7 +717,7 @@ DBIx::Lite::ResultSet
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 OVERVIEW
 
@@ -1160,7 +1160,7 @@ Alessandro Ranellucci <aar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Alessandro Ranellucci.
+This software is copyright (c) 2021 by Alessandro Ranellucci.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
